# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PaymentService(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "payment_service_id": "str",
        "payment_service_name": "str",
        "payment_service_url": "str",
        "pay_now_text": "str",
        "payment_service_type": "str",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "payment_service_id": "PaymentServiceID",
        "payment_service_name": "PaymentServiceName",
        "payment_service_url": "PaymentServiceUrl",
        "pay_now_text": "PayNowText",
        "payment_service_type": "PaymentServiceType",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        payment_service_id=None,
        payment_service_name=None,
        payment_service_url=None,
        pay_now_text=None,
        payment_service_type=None,
        validation_errors=None,
    ):  # noqa: E501
        """PaymentService - a model defined in OpenAPI"""  # noqa: E501

        self._payment_service_id = None
        self._payment_service_name = None
        self._payment_service_url = None
        self._pay_now_text = None
        self._payment_service_type = None
        self._validation_errors = None
        self.discriminator = None

        if payment_service_id is not None:
            self.payment_service_id = payment_service_id
        if payment_service_name is not None:
            self.payment_service_name = payment_service_name
        if payment_service_url is not None:
            self.payment_service_url = payment_service_url
        if pay_now_text is not None:
            self.pay_now_text = pay_now_text
        if payment_service_type is not None:
            self.payment_service_type = payment_service_type
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def payment_service_id(self):
        """Gets the payment_service_id of this PaymentService.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The payment_service_id of this PaymentService.  # noqa: E501
        :rtype: str
        """
        return self._payment_service_id

    @payment_service_id.setter
    def payment_service_id(self, payment_service_id):
        """Sets the payment_service_id of this PaymentService.

        Xero identifier  # noqa: E501

        :param payment_service_id: The payment_service_id of this PaymentService.  # noqa: E501
        :type: str
        """

        self._payment_service_id = payment_service_id

    @property
    def payment_service_name(self):
        """Gets the payment_service_name of this PaymentService.  # noqa: E501

        Name of payment service  # noqa: E501

        :return: The payment_service_name of this PaymentService.  # noqa: E501
        :rtype: str
        """
        return self._payment_service_name

    @payment_service_name.setter
    def payment_service_name(self, payment_service_name):
        """Sets the payment_service_name of this PaymentService.

        Name of payment service  # noqa: E501

        :param payment_service_name: The payment_service_name of this PaymentService.  # noqa: E501
        :type: str
        """

        self._payment_service_name = payment_service_name

    @property
    def payment_service_url(self):
        """Gets the payment_service_url of this PaymentService.  # noqa: E501

        The custom payment URL  # noqa: E501

        :return: The payment_service_url of this PaymentService.  # noqa: E501
        :rtype: str
        """
        return self._payment_service_url

    @payment_service_url.setter
    def payment_service_url(self, payment_service_url):
        """Sets the payment_service_url of this PaymentService.

        The custom payment URL  # noqa: E501

        :param payment_service_url: The payment_service_url of this PaymentService.  # noqa: E501
        :type: str
        """

        self._payment_service_url = payment_service_url

    @property
    def pay_now_text(self):
        """Gets the pay_now_text of this PaymentService.  # noqa: E501

        The text displayed on the Pay Now button in Xero Online Invoicing. If this is not set it will default to Pay by credit card  # noqa: E501

        :return: The pay_now_text of this PaymentService.  # noqa: E501
        :rtype: str
        """
        return self._pay_now_text

    @pay_now_text.setter
    def pay_now_text(self, pay_now_text):
        """Sets the pay_now_text of this PaymentService.

        The text displayed on the Pay Now button in Xero Online Invoicing. If this is not set it will default to Pay by credit card  # noqa: E501

        :param pay_now_text: The pay_now_text of this PaymentService.  # noqa: E501
        :type: str
        """

        self._pay_now_text = pay_now_text

    @property
    def payment_service_type(self):
        """Gets the payment_service_type of this PaymentService.  # noqa: E501

        This will always be CUSTOM for payment services created via the API.  # noqa: E501

        :return: The payment_service_type of this PaymentService.  # noqa: E501
        :rtype: str
        """
        return self._payment_service_type

    @payment_service_type.setter
    def payment_service_type(self, payment_service_type):
        """Sets the payment_service_type of this PaymentService.

        This will always be CUSTOM for payment services created via the API.  # noqa: E501

        :param payment_service_type: The payment_service_type of this PaymentService.  # noqa: E501
        :type: str
        """

        self._payment_service_type = payment_service_type

    @property
    def validation_errors(self):
        """Gets the validation_errors of this PaymentService.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this PaymentService.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this PaymentService.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this PaymentService.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero OAuth 2 Identity Service API

    These endpoints are related to managing authentication tokens and identity for Xero API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""

"""
    OpenAPI spec version: 2.10.4
"""

import importlib
import re  # noqa: F401

from xero_python import exceptions
from xero_python.api_client import ApiClient, ModelFinder

try:
    from .exception_handler import translate_status_exception
except ImportError:
    translate_status_exception = exceptions.translate_status_exception


class empty:
    """ empty object to mark optional parameter not set """


class IdentityApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    base_url = "https://api.xero.com"
    models_module = importlib.import_module("xero_python.identity.models")

    def __init__(self, api_client=None, base_url=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.base_url = base_url or self.base_url

    def get_resource_url(self, resource_path):
        """
        Combine API base url with resource specific path
        :param str resource_path: API endpoint specific path
        :return: str full resource path
        """
        return self.base_url + resource_path

    def get_model_finder(self):
        return ModelFinder(self.models_module)

    def delete_connection(
        self,
        id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Deletes a connection for this user (i.e. disconnect a tenant)  # noqa: E501
        OAuth2 scope: N/A
        Override the base server url that include version  # noqa: E501
        :param str id: Unique identifier for retrieving single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'id' is set
        if id is None:
            raise ValueError(
                "Missing the required parameter `id` "
                "when calling `delete_connection`"
            )

        collection_formats = {}
        path_params = {
            "id": id,
        }

        query_params = []

        header_params = {}

        local_var_files = {}
        form_params = []

        body_params = None
        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Connections/{id}")

        try:
            return self.api_client.call_api(
                url,
                "DELETE",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "delete_connection")

    def get_connections(
        self,
        auth_event_id=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves the connections for this user  # noqa: E501
        OAuth2 scope: N/A
        Override the base server url that include version  # noqa: E501
        :param str auth_event_id: Filter by authEventId
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: list[Connection]
        """

        collection_formats = {}
        path_params = {}

        query_params = []

        if auth_event_id is not empty:
            query_params.append(("authEventId", auth_event_id))

        header_params = {}

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Connections")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="list[Connection]",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_connections")



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeTax(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "starter_type": "str",
        "starter_declaration": "str",
        "tax_code": "str",
        "w1_m1": "bool",
        "previous_taxable_pay": "float",
        "previous_tax_paid": "float",
        "student_loan_deduction": "str",
        "has_post_graduate_loans": "bool",
        "is_director": "bool",
        "directorship_start_date": "date",
        "nic_calculation_method": "str",
    }

    attribute_map = {
        "starter_type": "starterType",
        "starter_declaration": "starterDeclaration",
        "tax_code": "taxCode",
        "w1_m1": "w1M1",
        "previous_taxable_pay": "previousTaxablePay",
        "previous_tax_paid": "previousTaxPaid",
        "student_loan_deduction": "studentLoanDeduction",
        "has_post_graduate_loans": "hasPostGraduateLoans",
        "is_director": "isDirector",
        "directorship_start_date": "directorshipStartDate",
        "nic_calculation_method": "nicCalculationMethod",
    }

    def __init__(
        self,
        starter_type=None,
        starter_declaration=None,
        tax_code=None,
        w1_m1=None,
        previous_taxable_pay=None,
        previous_tax_paid=None,
        student_loan_deduction=None,
        has_post_graduate_loans=None,
        is_director=None,
        directorship_start_date=None,
        nic_calculation_method=None,
    ):  # noqa: E501
        """EmployeeTax - a model defined in OpenAPI"""  # noqa: E501

        self._starter_type = None
        self._starter_declaration = None
        self._tax_code = None
        self._w1_m1 = None
        self._previous_taxable_pay = None
        self._previous_tax_paid = None
        self._student_loan_deduction = None
        self._has_post_graduate_loans = None
        self._is_director = None
        self._directorship_start_date = None
        self._nic_calculation_method = None
        self.discriminator = None

        if starter_type is not None:
            self.starter_type = starter_type
        if starter_declaration is not None:
            self.starter_declaration = starter_declaration
        if tax_code is not None:
            self.tax_code = tax_code
        if w1_m1 is not None:
            self.w1_m1 = w1_m1
        if previous_taxable_pay is not None:
            self.previous_taxable_pay = previous_taxable_pay
        if previous_tax_paid is not None:
            self.previous_tax_paid = previous_tax_paid
        if student_loan_deduction is not None:
            self.student_loan_deduction = student_loan_deduction
        if has_post_graduate_loans is not None:
            self.has_post_graduate_loans = has_post_graduate_loans
        if is_director is not None:
            self.is_director = is_director
        if directorship_start_date is not None:
            self.directorship_start_date = directorship_start_date
        if nic_calculation_method is not None:
            self.nic_calculation_method = nic_calculation_method

    @property
    def starter_type(self):
        """Gets the starter_type of this EmployeeTax.  # noqa: E501

        The Starter type.  # noqa: E501

        :return: The starter_type of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._starter_type

    @starter_type.setter
    def starter_type(self, starter_type):
        """Sets the starter_type of this EmployeeTax.

        The Starter type.  # noqa: E501

        :param starter_type: The starter_type of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._starter_type = starter_type

    @property
    def starter_declaration(self):
        """Gets the starter_declaration of this EmployeeTax.  # noqa: E501

        Starter declaration.  # noqa: E501

        :return: The starter_declaration of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._starter_declaration

    @starter_declaration.setter
    def starter_declaration(self, starter_declaration):
        """Sets the starter_declaration of this EmployeeTax.

        Starter declaration.  # noqa: E501

        :param starter_declaration: The starter_declaration of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._starter_declaration = starter_declaration

    @property
    def tax_code(self):
        """Gets the tax_code of this EmployeeTax.  # noqa: E501

        The Tax code.  # noqa: E501

        :return: The tax_code of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._tax_code

    @tax_code.setter
    def tax_code(self, tax_code):
        """Sets the tax_code of this EmployeeTax.

        The Tax code.  # noqa: E501

        :param tax_code: The tax_code of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._tax_code = tax_code

    @property
    def w1_m1(self):
        """Gets the w1_m1 of this EmployeeTax.  # noqa: E501

        Describes whether the tax settings is W1M1  # noqa: E501

        :return: The w1_m1 of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._w1_m1

    @w1_m1.setter
    def w1_m1(self, w1_m1):
        """Sets the w1_m1 of this EmployeeTax.

        Describes whether the tax settings is W1M1  # noqa: E501

        :param w1_m1: The w1_m1 of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._w1_m1 = w1_m1

    @property
    def previous_taxable_pay(self):
        """Gets the previous_taxable_pay of this EmployeeTax.  # noqa: E501

        The previous taxable pay  # noqa: E501

        :return: The previous_taxable_pay of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._previous_taxable_pay

    @previous_taxable_pay.setter
    def previous_taxable_pay(self, previous_taxable_pay):
        """Sets the previous_taxable_pay of this EmployeeTax.

        The previous taxable pay  # noqa: E501

        :param previous_taxable_pay: The previous_taxable_pay of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._previous_taxable_pay = previous_taxable_pay

    @property
    def previous_tax_paid(self):
        """Gets the previous_tax_paid of this EmployeeTax.  # noqa: E501

        The tax amount previously paid  # noqa: E501

        :return: The previous_tax_paid of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._previous_tax_paid

    @previous_tax_paid.setter
    def previous_tax_paid(self, previous_tax_paid):
        """Sets the previous_tax_paid of this EmployeeTax.

        The tax amount previously paid  # noqa: E501

        :param previous_tax_paid: The previous_tax_paid of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._previous_tax_paid = previous_tax_paid

    @property
    def student_loan_deduction(self):
        """Gets the student_loan_deduction of this EmployeeTax.  # noqa: E501

        The employee's student loan deduction type  # noqa: E501

        :return: The student_loan_deduction of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._student_loan_deduction

    @student_loan_deduction.setter
    def student_loan_deduction(self, student_loan_deduction):
        """Sets the student_loan_deduction of this EmployeeTax.

        The employee's student loan deduction type  # noqa: E501

        :param student_loan_deduction: The student_loan_deduction of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._student_loan_deduction = student_loan_deduction

    @property
    def has_post_graduate_loans(self):
        """Gets the has_post_graduate_loans of this EmployeeTax.  # noqa: E501

        Describes whether the employee has post graduate loans  # noqa: E501

        :return: The has_post_graduate_loans of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._has_post_graduate_loans

    @has_post_graduate_loans.setter
    def has_post_graduate_loans(self, has_post_graduate_loans):
        """Sets the has_post_graduate_loans of this EmployeeTax.

        Describes whether the employee has post graduate loans  # noqa: E501

        :param has_post_graduate_loans: The has_post_graduate_loans of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._has_post_graduate_loans = has_post_graduate_loans

    @property
    def is_director(self):
        """Gets the is_director of this EmployeeTax.  # noqa: E501

        Describes whether the employee is director  # noqa: E501

        :return: The is_director of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._is_director

    @is_director.setter
    def is_director(self, is_director):
        """Sets the is_director of this EmployeeTax.

        Describes whether the employee is director  # noqa: E501

        :param is_director: The is_director of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._is_director = is_director

    @property
    def directorship_start_date(self):
        """Gets the directorship_start_date of this EmployeeTax.  # noqa: E501

        The directorship start date  # noqa: E501

        :return: The directorship_start_date of this EmployeeTax.  # noqa: E501
        :rtype: date
        """
        return self._directorship_start_date

    @directorship_start_date.setter
    def directorship_start_date(self, directorship_start_date):
        """Sets the directorship_start_date of this EmployeeTax.

        The directorship start date  # noqa: E501

        :param directorship_start_date: The directorship_start_date of this EmployeeTax.  # noqa: E501
        :type: date
        """

        self._directorship_start_date = directorship_start_date

    @property
    def nic_calculation_method(self):
        """Gets the nic_calculation_method of this EmployeeTax.  # noqa: E501

        NICs calculation method  # noqa: E501

        :return: The nic_calculation_method of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._nic_calculation_method

    @nic_calculation_method.setter
    def nic_calculation_method(self, nic_calculation_method):
        """Sets the nic_calculation_method of this EmployeeTax.

        NICs calculation method  # noqa: E501

        :param nic_calculation_method: The nic_calculation_method of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._nic_calculation_method = nic_calculation_method



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Purchase(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "unit_price": "float",
        "account_code": "str",
        "cogs_account_code": "str",
        "tax_type": "str",
    }

    attribute_map = {
        "unit_price": "UnitPrice",
        "account_code": "AccountCode",
        "cogs_account_code": "COGSAccountCode",
        "tax_type": "TaxType",
    }

    def __init__(
        self, unit_price=None, account_code=None, cogs_account_code=None, tax_type=None
    ):  # noqa: E501
        """Purchase - a model defined in OpenAPI"""  # noqa: E501

        self._unit_price = None
        self._account_code = None
        self._cogs_account_code = None
        self._tax_type = None
        self.discriminator = None

        if unit_price is not None:
            self.unit_price = unit_price
        if account_code is not None:
            self.account_code = account_code
        if cogs_account_code is not None:
            self.cogs_account_code = cogs_account_code
        if tax_type is not None:
            self.tax_type = tax_type

    @property
    def unit_price(self):
        """Gets the unit_price of this Purchase.  # noqa: E501

        Unit Price of the item. By default UnitPrice is rounded to two decimal places. You can use 4 decimal places by adding the unitdp=4 querystring parameter to your request.  # noqa: E501

        :return: The unit_price of this Purchase.  # noqa: E501
        :rtype: float
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """Sets the unit_price of this Purchase.

        Unit Price of the item. By default UnitPrice is rounded to two decimal places. You can use 4 decimal places by adding the unitdp=4 querystring parameter to your request.  # noqa: E501

        :param unit_price: The unit_price of this Purchase.  # noqa: E501
        :type: float
        """

        self._unit_price = unit_price

    @property
    def account_code(self):
        """Gets the account_code of this Purchase.  # noqa: E501

        Default account code to be used for purchased/sale. Not applicable to the purchase details of tracked items  # noqa: E501

        :return: The account_code of this Purchase.  # noqa: E501
        :rtype: str
        """
        return self._account_code

    @account_code.setter
    def account_code(self, account_code):
        """Sets the account_code of this Purchase.

        Default account code to be used for purchased/sale. Not applicable to the purchase details of tracked items  # noqa: E501

        :param account_code: The account_code of this Purchase.  # noqa: E501
        :type: str
        """

        self._account_code = account_code

    @property
    def cogs_account_code(self):
        """Gets the cogs_account_code of this Purchase.  # noqa: E501

        Cost of goods sold account. Only applicable to the purchase details of tracked items.  # noqa: E501

        :return: The cogs_account_code of this Purchase.  # noqa: E501
        :rtype: str
        """
        return self._cogs_account_code

    @cogs_account_code.setter
    def cogs_account_code(self, cogs_account_code):
        """Sets the cogs_account_code of this Purchase.

        Cost of goods sold account. Only applicable to the purchase details of tracked items.  # noqa: E501

        :param cogs_account_code: The cogs_account_code of this Purchase.  # noqa: E501
        :type: str
        """

        self._cogs_account_code = cogs_account_code

    @property
    def tax_type(self):
        """Gets the tax_type of this Purchase.  # noqa: E501

        The tax type from TaxRates  # noqa: E501

        :return: The tax_type of this Purchase.  # noqa: E501
        :rtype: str
        """
        return self._tax_type

    @tax_type.setter
    def tax_type(self, tax_type):
        """Sets the tax_type of this Purchase.

        The tax type from TaxRates  # noqa: E501

        :param tax_type: The tax_type of this Purchase.  # noqa: E501
        :type: str
        """

        self._tax_type = tax_type
